==> paraview_5.9.0.orig.tar.xz: paraview-5.9.0/Qt/ApplicationComponents/pqApplicationSettingsReaction.h <==
/*=========================================================================

   Program: ParaView
   Module:    pqApplicationSettingsReaction.h

   Copyright (c) 2005,2006 Sandia Corporation, Kitware Inc.
   All rights reserved.

   ParaView is a free software; you can redistribute it and/or modify it
   under the terms of the ParaView license version 1.2.

   See License_v1.2.txt for the full ParaView license.
   A copy of this license can be obtained by contacting
   Kitware Inc.
   28 Corporate Drive
   Clifton Park, NY 12065
   USA

THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS
``AS IS'' AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT
LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR
A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE AUTHORS OR
CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL,
EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,
PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR
PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF
LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING
NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS
SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.

========================================================================*/
#ifndef pqApplicationSettingsReaction_h
#define pqApplicationSettingsReaction_h

#include "pqReaction.h"
#include <QPointer>

class pqSettingsDialog;

/**
* @ingroup Reactions
* pqApplicationSettingsReaction is a reaction to popup the application
* settings dialog. It creates pqSettingsDialog when required.
*/
class PQAPPLICATIONCOMPONENTS_EXPORT pqApplicationSettingsReaction : public pqReaction
{
  Q_OBJECT
  typedef pqReaction Superclass;

public:
  /**
  * Constructor. Parent cannot be NULL.
  */
  pqApplicationSettingsReaction(QAction* parent);
  ~pqApplicationSettingsReaction() override;

  /**
  * Show the application settings dialog.
  */
  static void showApplicationSettingsDialog(const QString& tabName = "");

protected:
  /**
  * Called when the action is triggered.
  */
  void onTriggered() override { pqApplicationSettingsReaction::showApplicationSettingsDialog(); }

private:
  Q_DISABLE_COPY(pqApplicationSettingsReaction)

  static QPointer<pqSettingsDialog> Dialog;
};

#endif

==> paraview_5.10.0~rc1.orig.tar.xz: paraview-5.10.0~rc1/Qt/ApplicationComponents/pqApplicationSettingsReaction.h <==
/*=========================================================================

   Program: ParaView
   Module:    pqApplicationSettingsReaction.h

   Copyright (c) 2005,2006 Sandia Corporation, Kitware Inc.
   All rights reserved.

   ParaView is a free software; you can redistribute it and/or modify it
   under the terms of the ParaView license version 1.2.

   See License_v1.2.txt for the full ParaView license.
   A copy of this license can be obtained by contacting
   Kitware Inc.
   28 Corporate Drive
   Clifton Park, NY 12065
   USA

THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS
``AS IS'' AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT
LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR
A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE AUTHORS OR
CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL,
EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,
PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR
PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF
LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING
NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS
SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.

========================================================================*/
#ifndef pqApplicationSettingsReaction_h
#define pqApplicationSettingsReaction_h

#include "pqReaction.h"
#include <QPointer>

class pqSettingsDialog;

/**
 * @ingroup Reactions
 * pqApplicationSettingsReaction is a reaction to popup the application
 * settings dialog. It creates pqSettingsDialog when required.
 */
class PQAPPLICATIONCOMPONENTS_EXPORT pqApplicationSettingsReaction : public pqReaction
{
  Q_OBJECT
  typedef pqReaction Superclass;

public:
  /**
   * Constructor. Parent cannot be nullptr.
   */
  pqApplicationSettingsReaction(QAction* parent);
  ~pqApplicationSettingsReaction() override;

  /**
   * Show the application settings dialog.
   */
  static void showApplicationSettingsDialog(const QString& tabName = "");

protected:
  /**
   * Called when the action is triggered.
   */
  void onTriggered() override { pqApplicationSettingsReaction::showApplicationSettingsDialog(); }

private:
  Q_DISABLE_COPY(pqApplicationSettingsReaction)

  static QPointer<pqSettingsDialog> Dialog;
};

#endif
